@@ -1,17 +1,11 @@
 #!/bin/bash
 
-if [ $(uname) == Darwin ]; then
-    SONAME="dylib"
-else
-    SONAME="so"
-fi
-
 cmake -D CMAKE_INSTALL_PREFIX=$PREFIX \
-      -D TIFF_LIBRARY=$PREFIX/lib/libtiff.${SONAME} \
+      -D TIFF_LIBRARY=$PREFIX/lib/libtiff${SHLIB_EXT} \
       -D TIFF_INCLUDE_DIR=$PREFIX/include \
-      -D PNG_LIBRARY_RELEASE=$PREFIX/lib/libpng.${SONAME} \
+      -D PNG_LIBRARY_RELEASE=$PREFIX/lib/libpng${SHLIB_EXT} \
       -D PNG_PNG_INCLUDE_DIR=$PREFIX/include \
-      -D ZLIB_LIBRARY=$PREFIX/lib/libz.${SONAME} \
+      -D ZLIB_LIBRARY=$PREFIX/lib/libz${SHLIB_EXT} \
       -D ZLIB_INCLUDE_DIR=$PREFIX/include \
       .
 
